@@ -171,7 +171,9 @@ PreferredMIMENames[] =
   { "l8",		"iso-8859-14"	},
 
   { "iso_8859-15",	"iso-8859-15"	},
-
+  { "latin9",		"iso-8859-15"	}, /* this is not a bug */
+  
+  
   /*
    * If you happen to encounter system-specific brain-damage with
    * respect to character set naming, please add it here, and
@@ -239,19 +241,20 @@ void mutt_canonical_charset (char *dest, size_t dlen, const char *name)
   char scratch[LONG_STRING];
 
   /* catch some common iso-8859-something misspellings */
-  if (!mutt_strncasecmp (name, "8859", 4) && name[4] != '-')
+  if (!ascii_strncasecmp (name, "8859", 4) && name[4] != '-')
     snprintf (scratch, sizeof (scratch), "iso-8859-%s", name +4);
-  else if (!mutt_strncasecmp (name, "8859-", 5))
+  else if (!ascii_strncasecmp (name, "8859-", 5))
     snprintf (scratch, sizeof (scratch), "iso-8859-%s", name + 5);
-  else if (!mutt_strncasecmp (name, "iso8859", 7) && name[7] != '-')
+  else if (!ascii_strncasecmp (name, "iso8859", 7) && name[7] != '-')
     snprintf (scratch, sizeof (scratch), "iso_8859-%s", name + 7);
-  else if (!mutt_strncasecmp (name, "iso8859-", 8))
+  else if (!ascii_strncasecmp (name, "iso8859-", 8))
     snprintf (scratch, sizeof (scratch), "iso_8859-%s", name + 8);
   else
     strfcpy (scratch, NONULL(name), sizeof (scratch));
 
   for (i = 0; PreferredMIMENames[i].key; i++)
-    if (!mutt_strcasecmp (scratch, PreferredMIMENames[i].key))
+    if (!ascii_strcasecmp (scratch, PreferredMIMENames[i].key) ||
+	!mutt_strcasecmp (scratch, PreferredMIMENames[i].key))
     {
       strfcpy (dest, PreferredMIMENames[i].pref, dlen);
       return;
@@ -261,8 +264,7 @@ void mutt_canonical_charset (char *dest, size_t dlen, const char *name)
 
   /* for cosmetics' sake, transform to lowercase. */
   for (p = dest; *p; p++)
-    if (isupper (*p))
-      *p = tolower (*p);
+    *p = ascii_tolower (*p);
 }
 
 int mutt_chscmp (const char *s, const char *chs)
@@ -272,7 +274,7 @@ int mutt_chscmp (const char *s, const char *chs)
   if (!s) return 0;
 
   mutt_canonical_charset (buffer, sizeof (buffer), s);
-  return !mutt_strcasecmp (buffer, chs);
+  return !ascii_strcasecmp (buffer, chs);
 }
 
 
