@@ -236,8 +236,10 @@ void mutt_decode_quoted (STATE *s, long len, int istext, iconv_t cd)
   char decline[2*STRING];
   size_t l = 0;
   size_t l2;
+  size_t l3;
 
-  state_set_prefix(s);
+  if (istext)
+    state_set_prefix(s);
 
   while (len > 0)
   {
@@ -260,7 +262,8 @@ void mutt_decode_quoted (STATE *s, long len, int istext, iconv_t cd)
      * decode and do character set conversion
      */
     
-    qp_decode_line (decline + l, line, &l);
+    qp_decode_line (decline + l, line, &l3);
+    l += l3;
     convert_to_state (cd, decline, &l, s);
   }
 
@@ -277,7 +280,8 @@ void mutt_decode_base64 (STATE *s, long len, int istext, iconv_t cd)
 
   buf[4] = 0;
 
-  if (istext) state_set_prefix(s);
+  if (istext) 
+    state_set_prefix(s);
 
   while (len > 0)
   {
@@ -882,6 +886,285 @@ void text_enriched_handler (BODY *a, STATE *s)
   FREE (&(stte.param));
 }                                                                              
 
+/*
+ * An implementation of RFC 2646.
+ * 
+ */
+
+#define FLOWED_MAX 77
+
+static void flowed_quote (STATE *s, int level)
+{
+  int i;
+  
+  if (s->prefix)
+  {
+    if (option (OPTTEXTFLOWED))
+      level++;
+    else
+      state_puts (s->prefix, s);
+  }
+  
+  for (i = 0; i < level; i++)
+    state_putc ('>', s);
+}
+
+static int flowed_maybe_quoted (char *cont)
+{
+  return regexec ((regex_t *) QuoteRegexp.rx, cont, 0, NULL, 0) == 0;
+}
+
+static void flowed_stuff (STATE *s, char *cont, int level)
+{
+  if (!option (OPTTEXTFLOWED) && !(s->flags & M_DISPLAY))
+    return;
+
+  if (s->flags & M_DISPLAY)
+  {
+    /* 
+     * Hack: If we are in the beginning of the line and there is 
+     * some text on the line which looks like it's quoted, turn off 
+     * ANSI colors, so quote coloring doesn't affect this line. 
+     */
+    if (*cont && !level && flowed_maybe_quoted (cont))
+      state_puts ("\033[0;m",s);
+  }
+  else if ((*cont == ' ') || (*cont == '>') || (!level && !mutt_strncmp (cont, "From ", 5)))
+    state_putc (' ', s);
+}
+
+static char *flowed_skip_indent (char *prefix, char *cont)
+{
+  for (; *cont == ' ' || *cont == '\t'; cont++)
+    *prefix++ = *cont;
+  *prefix = '\0';
+  return cont;
+}
+
+static void text_plain_flowed_handler (BODY *a, STATE *s)
+{
+  char line[LONG_STRING];
+  char indent[LONG_STRING];
+
+  int  quoted = -1;
+  int  last_quoted;
+  int  full = 1;
+  int  last_full;
+  int  col = 0;
+
+  int  add = 0;
+  int  soft = 0;
+  int  max;
+  int  l;
+  
+  int  flowed_max;
+  int  bytes = a->length;
+  int  actually_wrap = 0;
+  
+  char *cont = NULL;
+  char *tail = NULL;
+  char *lc = NULL;
+  char *t;
+
+  *indent = '\0';
+  
+  if (s->prefix)
+    add = 1;
+  
+  if ((flowed_max = FLOWED_MAX) > COLS - 3)
+    flowed_max = COLS - 3;
+
+  while (bytes > 0 && fgets (line, sizeof (line), s->fpin))
+  {
+    bytes        -= strlen (line);
+    tail          = NULL;
+
+    last_full     = full;
+    
+    /* 
+     * If the last line wasn't fully read, this is the
+     * tail of some line. 
+     */
+    actually_wrap = !last_full; 
+    
+    if ((t = strrchr (line, '\r')) || (t = strrchr (line, '\n')))
+    {
+      *t   = '\0';
+      full = 1;
+    }
+    else if ((t = strrchr (line, ' ')) || (t = strrchr (line, '\t')))
+    {
+      /* 
+       * Bad: We have a line of more than LONG_STRING characters.
+       * (Which SHOULD NOT happen, since lines SHOULD be <= 79
+       * characters long.)
+       * 
+       * Try to simulate a soft line break at a word boundary.
+       * Handle the rest of the line next time.
+       * 
+       * Give up when we have a single word which is longer than
+       * LONG_STRING characters.  It will just be split into parts,
+       * with a hard line break in between. 
+       */
+
+      full = 0;
+      l    = strlen (t + 1);
+      t[0] = ' ';
+      t[1] = '\0';
+
+      if (l)
+      {
+	fseek (s->fpin, -l, SEEK_CUR);
+	bytes += l;
+      }
+    }
+    else
+      full = 0;
+
+    last_quoted = quoted;
+
+    if (last_full)
+    {
+      /* 
+       * We are in the beginning of a new line. Determine quote level
+       * and indentation prefix 
+       */
+      for (quoted = 0; line[quoted] == '>'; quoted++)
+	;
+      
+      cont = line + quoted;
+      
+      /* undo space stuffing */
+      if (*cont == ' ')
+	cont++;
+
+      /* If there is an indentation, record it. */
+      cont = flowed_skip_indent (indent, cont);
+    }
+    else
+    {
+      /* 
+       * This is just the tail of some over-long line. Keep
+       * indentation and quote levels.  Don't unstuff.
+       */
+      cont = line;
+    }
+
+    /* If we have a change in quoting depth, wrap. */
+
+    if (col && last_quoted != quoted && last_quoted >= 0)
+    {
+      state_putc ('\n', s);
+      col = 0;
+    }
+    
+    do 
+    {
+      if (tail)
+	cont = tail;
+
+      SKIPWS (cont);
+      
+      tail = NULL;
+      soft = 0;
+      
+      /* try to find a point for word wrapping */
+
+    retry_wrap:
+      l = mutt_strlen (cont);
+      if (quoted + add + col + l > flowed_max)
+      {
+	actually_wrap = 1;
+	if ((max = flowed_max - quoted - add - col)
+	    > l)
+	  max = l;
+
+	for (t = cont + max; t > cont; t--)
+	{
+	  if (*t == ' ' || *t == '\t')
+	  {
+	    tail = t;
+	    break;
+	  }
+	}
+
+	if (tail)
+	{
+	  *tail++ = '\0';
+	  soft = 2;
+	}
+      }
+
+      /* We seem to be desperate.  Get me a new line, and retry. */
+      if (!tail && (quoted + add + col + mutt_strlen (cont) > flowed_max) && col)
+      {
+	state_putc ('\n', s);
+	col = 0;
+	goto retry_wrap;
+      }
+
+      /* Detect soft line breaks. */
+      if (!soft && ascii_strcmp (cont, "-- "))
+      {
+	lc = strrchr (cont, ' ');
+	if (lc && lc[1] == '\0')
+	  soft = 1;
+      }
+
+      /* 
+       * If we are in the beginning of an output line, do quoting
+       * and stuffing. 
+       * 
+       * We have to temporarily assemble the line since display
+       * stuffing (i.e., turning off quote coloring) may depend on
+       * the line's actual content.  You never know what people put
+       * into their regular expressions. 
+       */
+      if (!col)
+      {
+	char tmp[LONG_STRING];
+	snprintf (tmp, sizeof (tmp), "%s%s", indent, cont);
+
+	flowed_quote (s, quoted);
+	flowed_stuff (s, tmp, quoted + add);
+
+	state_puts (indent, s);
+      }
+
+      /* output the text */
+      state_puts (cont, s);
+      col += strlen (cont);
+      
+      /* possibly indicate a soft line break */
+      if (soft == 2)
+      {
+	state_putc (' ', s);
+	col++;
+      }
+      
+      /* 
+       * Wrap if this display line corresponds to a 
+       * text line. Don't wrap if we changed the line.
+       */
+      if (!soft || (!actually_wrap && full))
+      {
+	state_putc ('\n', s);
+	col = 0;
+      }
+    }
+    while (tail);
+  }
+
+  if (col)
+    state_putc ('\n', s);
+  
+}
+
+
+
+
+
+
 #define TXTHTML     1
 #define TXTPLAIN    2
 #define TXTENRICHED 3
@@ -1218,18 +1501,26 @@ void autoview_handler (BODY *a, STATE *s)
 
     if(!piped)
     {
-      fclose (fpin);
+      safe_fclose (&fpin);
       thepid = mutt_create_filter (command, NULL, &fpout, &fperr);
     }
     else
     {
-      unlink(tempfile);
-      fflush(fpin);
-      rewind(fpin);
+      unlink (tempfile);
+      fflush (fpin);
+      rewind (fpin);
       thepid = mutt_create_filter_fd (command, NULL, &fpout, &fperr,
 				      fileno(fpin), -1, -1);
     }
 
+    if (thepid < 0)
+    {
+      mutt_perror _("Can't create filter");
+      if (s->flags & M_DISPLAY)
+	state_printf (s, _("[-- Can't run %s. --]\n"), command);
+      goto bail;
+    }
+    
     if (s->prefix)
     {
       while (fgets (buffer, sizeof(buffer), fpout) != NULL)
@@ -1267,11 +1558,13 @@ void autoview_handler (BODY *a, STATE *s)
       }
     }
 
-    fclose (fpout);
-    fclose (fperr);
+  bail:
+    safe_fclose (&fpout);
+    safe_fclose (&fperr);
+
     mutt_wait_filter (thepid);
-    if(piped)
-      fclose(fpin);
+    if (piped)
+      safe_fclose (&fpin);
     else
       mutt_unlink (tempfile);
 
@@ -1419,7 +1712,10 @@ void mutt_body_handler (BODY *b, STATE *s)
       /* avoid copying this part twice since removing the transfer-encoding is
        * the only operation needed.
        */
-      plaintext = 1;
+      if (ascii_strcasecmp ("flowed", mutt_get_parameter ("format", b->parameter)) == 0)
+	handler = text_plain_flowed_handler;
+      else
+	plaintext = 1;
     }
     else if (ascii_strcasecmp ("enriched", b->subtype) == 0)
       handler = text_enriched_handler;
@@ -1500,7 +1796,12 @@ void mutt_body_handler (BODY *b, STATE *s)
 
     /* see if we need to decode this part before processing it */
     if (b->encoding == ENCBASE64 || b->encoding == ENCQUOTEDPRINTABLE ||
-	b->encoding == ENCUUENCODED || plaintext)
+	b->encoding == ENCUUENCODED || plaintext || 
+	mutt_is_text_type (b->type, b->subtype))	/* text subtypes may
+							 * require character
+							 * set conversion even
+							 * with 8bit encoding.
+							 */
     {
       int origType = b->type;
       char *savePrefix = NULL;
