@@ -37,11 +37,10 @@ void mutt_edit_headers (const char *editor,
   char *p;
   FILE *ifp, *ofp;
   int i, keep;
-  int in_reply_to = 0;	/* did we see the in-reply-to field ? */
   ENVELOPE *n;
   time_t mtime;
   struct stat st;
-  LIST *cur, *last = NULL, *tmp;
+  LIST *cur, **last = NULL, *tmp;
 
   mutt_mktemp (path);
   if ((ofp = safe_fopen (path, "w")) == NULL)
@@ -110,16 +109,21 @@ void mutt_edit_headers (const char *editor,
   /* restore old info. */
   n->references = msg->env->references;
   msg->env->references = NULL;
+
   mutt_free_envelope (&msg->env);
-  msg->env = n;
+  msg->env = n; n = NULL;
+
+  if (!msg->env->in_reply_to)
+    mutt_free_list (&msg->env->references);
 
   mutt_expand_aliases_env (msg->env);
-  
+
   /* search through the user defined headers added to see if either a 
    * fcc: or attach-file: field was specified.  
    */
 
   cur = msg->env->userhdrs;
+  last = &msg->env->userhdrs;
   while (cur)
   {
     keep = 1;
@@ -128,9 +132,7 @@ void mutt_edit_headers (const char *editor,
      * not, remove the references: field later so that we can generate a new
      * message based upon this one.
      */
-    if (ascii_strncasecmp ("in-reply-to:", cur->data, 12) == 0)
-      in_reply_to = 1;
-    else if (fcc && ascii_strncasecmp ("fcc:", cur->data, 4) == 0)
+    if (fcc && ascii_strncasecmp ("fcc:", cur->data, 4) == 0)
     {
       p = cur->data + 4;
       SKIPWS (p);
@@ -187,22 +189,16 @@ void mutt_edit_headers (const char *editor,
 
     if (keep)
     {
-      last = cur;
-      cur = cur->next;
+      last = &cur->next;
+      cur  = cur->next;
     }
     else
     {
-      if (last)
-	last->next = cur->next;
-      else
-	msg->env->userhdrs = cur->next;
-      tmp = cur;
-      cur = cur->next;
+      tmp       = cur;
+      *last     = cur->next;
+      cur       = cur->next;
       tmp->next = NULL;
       mutt_free_list (&tmp);
     }
   }
-
-  if (!in_reply_to)
-    mutt_free_list (&msg->env->references);
 }
