@@ -577,12 +577,14 @@ struct option_t MuttVars[] = {
   { "forw_quote",	DT_SYN,  R_NONE, UL "forward_quote", 0 },
   /*
   */
-  { "from",		DT_ADDR, R_NONE, UL &From, UL "" },
+  { "from",		DT_ADDR, R_NONE, UL &From, 0 },
   /*
   ** .pp
   ** When set, this variable contains a default from address.  It
   ** can be overridden using my_hdr (including from send-hooks) and
   ** ``$$reverse_name''.
+  ** .pp
+  ** Defaults to the EMAIL environment variable's content.
   */
   { "gecos_mask",	DT_RX,	 R_NONE, UL &GecosMask, UL "^[^,]*" },
   /*
@@ -850,6 +852,13 @@ struct option_t MuttVars[] = {
   ** .pp
   ** How to invoke ispell (GNU's spell-checking software).
   */
+  { "keep_flagged", DT_BOOL, R_NONE, OPTKEEPFLAGGED, 0 },
+  /*
+  ** .pp
+  ** If set, read messages marked as flagged will not be moved
+  ** from your spool mailbox to your ``$$mbox'' mailbox, or as a result of
+  ** a ``$mbox-hook'' command.
+  */
   { "locale",		DT_STR,  R_BOTH, UL &Locale, UL "C" },
   /*
   ** .pp
@@ -1438,6 +1447,27 @@ struct option_t MuttVars[] = {
   ** messages to an external Unix command.
   */
 #ifdef USE_POP
+  { "pop_authenticators", DT_STR, R_NONE, UL &PopAuthenticators, UL 0 },
+  /*
+  ** .pp
+  ** This is a colon-delimited list of authentication methods mutt may
+  ** attempt to use to log in to an POP server, in the order mutt should
+  ** try them.  Authentication methods are either 'user', 'apop' or any
+  ** SASL mechanism, eg 'digest-md5', 'gssapi' or 'cram-md5'.
+  ** This parameter is case-insensitive. If this parameter is unset
+  ** (the default) mutt will try all available methods, in order from
+  ** most-secure to least-secure.
+  ** .pp
+  ** Example: set pop_authenticators="digest-md5:apop:user"
+  */
+  { "pop_auth_try_all",	DT_BOOL, R_NONE, OPTPOPAUTHTRYALL, 1 },
+  /*
+  ** .pp
+  ** If set, Mutt will try all available methods. When unset, Mutt will
+  ** only fall back to other authentication methods if the previous
+  ** methods are unavailable. If a method is available but authentication
+  ** fails, Mutt will not connect to the POP server.
+  */
   { "pop_checkinterval", DT_NUM, R_NONE, UL &PopCheckTimeout, 60 },
   /*
   ** .pp
@@ -2335,6 +2365,9 @@ struct command_t
 };
 
 struct command_t Commands[] = {
+#ifdef USE_SOCKET
+  { "account-hook",     mutt_parse_hook,        M_ACCOUNTHOOK },
+#endif
   { "alias",		parse_alias,		0 },
   { "auto_view",	parse_list,		UL &AutoViewList },
   { "alternative_order",	parse_list,	UL &AlternativeOrderList},
