@@ -142,6 +142,7 @@ typedef enum
 #ifdef HAVE_PGP
 #define M_PGPHOOK	(1<<8)
 #endif
+#define M_ACCOUNTHOOK	(1<<9)
 
 /* tree characters for linearize_tree and print_enriched_string */
 #define M_TREE_LLCORNER		1
@@ -263,8 +264,10 @@ enum
   OPT_MIMEFWD,
   OPT_MOVE,
   OPT_COPY,
+#ifdef USE_POP
   OPT_POPDELETE,
   OPT_POPRECONNECT,
+#endif
   OPT_POSTPONE,
   OPT_QUIT,
   OPT_REPLYTO,
@@ -343,6 +346,7 @@ enum
   OPTSSLSYSTEMCERTS,
 #endif
   OPTIMPLICITAUTOVIEW,
+  OPTKEEPFLAGGED,
   OPTMAILCAPSANITIZE,
   OPTMAILDIRTRASH,
   OPTMARKERS,
@@ -355,7 +359,10 @@ enum
   OPTPAGERSTOP,
   OPTPIPEDECODE,
   OPTPIPESPLIT,
+#ifdef USE_POP
+  OPTPOPAUTHTRYALL,
   OPTPOPLAST,
+#endif
   OPTPRINTDECODE,
   OPTPRINTSPLIT,
   OPTPROMPTAFTER,
