@@ -223,6 +223,14 @@ void mutt_socket_free (CONNECTION* conn)
 CONNECTION* mutt_conn_find (const CONNECTION* start, const ACCOUNT* account)
 {
   CONNECTION* conn;
+  ciss_url_t url;
+  char hook[LONG_STRING];
+
+  /* account isn't actually modified, since url isn't either */
+  mutt_account_tourl ((ACCOUNT*) account, &url);
+  url.path = NULL;
+  url_ciss_tostring (&url, hook, sizeof (hook));
+  mutt_account_hook (hook);
 
   conn = start ? start->next : Connections;
   while (conn)
@@ -412,11 +420,11 @@ int raw_socket_open (CONNECTION* conn)
   for (cur = res; cur != NULL; cur = cur->ai_next)
   {
     fd = socket (cur->ai_family, cur->ai_socktype, cur->ai_protocol);
-    fcntl(fd,F_SETFD,FD_CLOEXEC);
     if (fd >= 0)
     {
       if ((rc = socket_connect (fd, cur->ai_addr)) == 0)
       {
+	fcntl (fd, F_SETFD, FD_CLOEXEC);
 	conn->fd = fd;
 	break;
       }
