@@ -15,17 +15,19 @@ url_scheme_t;
 
 typedef struct ciss_url
 {
+  url_scheme_t scheme;
   char *user;
   char *pass;
   char *host;
-  short port;
-  char  *path;
+  unsigned short port;
+  char *path;
 } 
 ciss_url_t;
 
 url_scheme_t url_check_scheme (const char *s);
 int url_parse_file (char *d, const char *src, size_t dl);
-int url_parse_ciss (ciss_url_t *ciss, const char *src);
+int url_parse_ciss (ciss_url_t *ciss, char *src);
+int url_ciss_tostring (ciss_url_t* ciss, char* dest, size_t len);
 int url_parse_mailto (ENVELOPE *e, char **body, const char *src);
 
 #endif
